package ch.epfl.tpp.sol;

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.image.BufferedImage;
import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import javax.swing.JComponent;
import javax.swing.JFrame;

import ch.epfl.tpp.sol.image.Image;

public class BarChartMakerGUI {
    private static List<Integer> readIntegerList(String fileName) throws IOException {
        List<Integer> numbers = new ArrayList<>();
        BufferedReader r = new BufferedReader(new FileReader(fileName));
        String line;
        while ((line = r.readLine()) != null)
            numbers.add(Integer.valueOf(line));
        r.close();
        return numbers;
    }
    
    private static Image createChartImage() {
        List<Integer> inData = Collections.emptyList(), scData = Collections.emptyList();
        try {
            inData = readIntegerList("in.txt");
            scData = readIntegerList("sc.txt");
        } catch (IOException e) {
            e.printStackTrace(System.err);
            System.exit(1);
        }
        Histogram inHistogram = new Histogram(inData);
        Histogram scHistogram = new Histogram(scData);
        Image i = ChartMaker.makeStackedBarChart(inHistogram, Color.MIDDLE_GREY, scHistogram, Color.DARK_GREY, 1, 0.1, Color.LIGHT_GREY);
        return i;
    }
    
    public static void main(String[] args) {
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
            @SuppressWarnings("serial")
            public void run() {
                JFrame frame = new JFrame("Image viewer");
                frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
                frame.add(new JComponent() {
                    @Override
                    public Dimension getPreferredSize() {
                        return new Dimension(800, 600);
                    }
                    
                    @Override
                    protected void paintComponent(Graphics g) {
                        Image image = createChartImage();
                        BufferedImage awtImage = new BufferedImage(getWidth(), getHeight(), BufferedImage.TYPE_INT_RGB);
                        double xRatio = image.width() / getWidth();
                        double yRatio = image.height() / getHeight();
                        
                        for (int x = 0; x < getWidth(); ++x) {
                            double imageX = x * xRatio;
                            for (int y = 0; y < getHeight(); ++y) {
                                double imageY = (getHeight() - y - 1) * yRatio;
                                float brightness = image.colorAtPoint(new Point(imageX, imageY)).brightness();
                                awtImage.setRGB(x, y, new java.awt.Color(brightness, brightness, brightness).getRGB());
                            }
                        }
                        g.drawImage(awtImage, 0, 0, null);
                    }
                });
                frame.pack();
                frame.setVisible(true);
            }
        }); 
    }
}