package ch.epfl.tpp.sol;

import ch.epfl.tpp.sol.image.FramedImage;
import ch.epfl.tpp.sol.image.HorizontalCompositeImage;
import ch.epfl.tpp.sol.image.Image;
import ch.epfl.tpp.sol.image.MonochromaticImage;
import ch.epfl.tpp.sol.image.VerticalCompositeImage;

public final class ChartMaker {
    private ChartMaker() {} // Forbid instantiation.
    
    public static Image makeBarChart(Histogram h, double barWidth, Color barColor, double frameWidth, Color backgroundColor) {
        Image finalImage = Image.EMPTY_IMAGE;
        for (int v = h.minValue(); v <= h.maxValue(); ++v) {
            double barHeight = h.valueCount(v);
            Image bar = new MonochromaticImage(barWidth, barHeight, barColor);
            Image framedBar = new FramedImage(bar, frameWidth, backgroundColor);
            finalImage = new HorizontalCompositeImage(finalImage, framedBar, backgroundColor);
        }
        return new FramedImage(finalImage, 3 * frameWidth, backgroundColor);
    }
    
    public static Image makeStackedBarChart(Histogram h1,
            Color barColor1,
            Histogram h2,
            Color barColor2,
            double barWidth,
            double frameWidth,
            Color backgroundColor) {
        Image finalImage = Image.EMPTY_IMAGE;
        for (int v = Math.min(h1.minValue(), h2.minValue()); v <= Math.max(h1.maxValue(), h2.maxValue()); ++v) {
            double barHeight1 = h1.valueCount(v);
            double barHeight2 = h2.valueCount(v);
            Image bar1 = new MonochromaticImage(barWidth, barHeight1, barColor1);
            Image bar2 = new MonochromaticImage(barWidth, barHeight2, barColor2);
            Image bars = new VerticalCompositeImage(bar2, bar1, backgroundColor);
            Image framedBars = new FramedImage(bars, frameWidth, backgroundColor);
            finalImage = new HorizontalCompositeImage(finalImage, framedBars, backgroundColor);
        }
        return new FramedImage(finalImage, 3 * frameWidth, backgroundColor);
    }
}
